import argparse
from .calculations import calculate_profit, calculate_roi


def main() -> None:
    parser = argparse.ArgumentParser(prog="finutils")
    parser.add_argument("--revenue", type=float, required=True)
    parser.add_argument("--costs", type=float, required=True)
    args = parser.parse_args()

    profit = calculate_profit(args.revenue, args.costs)
    roi = calculate_roi(args.revenue, args.costs)

    print(f"Чистая прибыль: {profit}\nROI: {roi}%")


if __name__ == "__main__":
    main()



def calculate_profit(revenue: float, costs: float) -> float:
    return revenue - costs


def calculate_roi(revenue: float, costs: float) -> float:
    profit = calculate_profit(revenue, costs)
    return (profit / costs) * 100


from setuptools import setup, find_packages

# Загрузка .egg на PyPI больше не поддерживается, поэтому загружаем wheel и sdist
def read(filename):
    with open(filename, "r", encoding="utf-8") as file:
        return file.read()

setup(
    name='finutils_scochilloff',
    version='0.1.1',
    long_description=read("README.md"),
    packages=find_packages(),
    install_requires=[],
)